/*
   Change the view frusturm's field-of-view (fov)
   to zoom in on the cow.

   Use the blue "dot" model to see where on the
   cow you are zooming in.
*/
import java.io.File;
import java.awt.Color;

public class ZoomIn
{
   public static void main(String[] args)
   {
      // Create several Model objects.
      Model cow = new ObjSimpleModel(new File("cow.obj"));
      for (Triangle t : cow.triangleList)
      {
         t.v[0].setColorRandom();
         t.setColor( t.v[0].getColor() );
      }
      cow.doLighting = false;
      cow.modelTranslate(0, 4, 0);
      cow.modelRotate(-60, 0,1,0);

      Model dot = new SphereModel(10, 10, 0.2);
      for (Triangle t : dot.triangleList)
      {
         t.setColor( Color.blue );
      }
      dot.doLighting = false;
      dot.modelTranslate(0, 4, 10);

      Model floor = new PanelModel(-7, 7, -7, 7, Color.white, Color.black);
      floor.doLighting = false;

      // Create the Scene object that we shall render
      Scene scene = new Scene();

      // Add the models to the Scene.
      scene.modelList.add(cow);
      scene.modelList.add(dot);
      scene.modelList.add(floor);

      // Give the Scene a view matrix.
      scene.view2Identity();

      // Give the scene a projection matrix.
      scene.proj2Identity();

      // Set up the scene's view frustum.
      double fov    = 60.0;
      double aspect = 1.0;
      double near   = 1.0;
      double far    = 30.0;
      scene.projPerspective(fov, aspect, near, far);


      // Set up the scene's "camera".
      double eyex=0,    eyey=4,    eyez=20;      // where the camera is
      double centerx=0, centery=4, centerz=0;    // where the camera is pointed
      double upx=0,     upy=1,     upz=0;        // where the "top" of the camera is pointed
      scene.viewLookAt(eyex,    eyey,    eyez,
                       centerx, centery, centerz,
                       upx,     upy,     upz);


      // Create a framebuffer to render our scene into.
      int vp_width  = 512;
      int vp_height = 512;
      FrameBuffer fb = new FrameBuffer(vp_width, vp_height);
      // Give the framebuffer a nice background color.
      fb.clearFB(java.awt.Color.darkGray);

      // Render our scene into the frame buffer.
      SceneRender.renderScene(scene, fb);

      // Save the resulting image in a file.
      fb.dumpFB2File( "ZoomIn.ppm" );
   }
}